/*
 * pdsnn.h
 * 
 * Copyright 2011 Fernando Pujaico Rivera <fernando.pujaico.rivera@gmail.com>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 * 
 */


#ifndef __PDSNN_H__
#define __PDSNN_H__

#define PDS_DEFAULT_MAX_RMS_ERROR 0.70711
#define PDS_DEFAULT_ALPHA 0.5
#define PDS_DEFAULT_MAX_ITER 0

#include <pds/pdsnnglobal.h>

#include <pds/pdsnivector.h>
#include <pds/pdsnvector.h>
#include <pds/pdsneuronml.h>

#endif /* __PDSNN_H__ */
